@@ -39,16 +39,20 @@ import org.eclipse.jetty.security.ConstraintSecurityHandler;
 import org.eclipse.jetty.security.HashLoginService;
 import org.eclipse.jetty.security.SecurityHandler;
 import org.eclipse.jetty.security.authentication.BasicAuthenticator;
+import org.eclipse.jetty.server.Connector;
+import org.eclipse.jetty.server.HttpConfiguration;
+import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.Request;
 import org.eclipse.jetty.server.Response;
 import org.eclipse.jetty.server.Server;
+import org.eclipse.jetty.server.ServerConnector;
 import org.eclipse.jetty.server.handler.AbstractHandler;
 import org.eclipse.jetty.server.handler.HandlerCollection;
-import org.eclipse.jetty.util.security.Constraint;
-import org.eclipse.jetty.util.security.Password;
 import org.eclipse.jetty.servlet.DefaultServlet;
 import org.eclipse.jetty.servlet.ServletContextHandler;
 import org.eclipse.jetty.servlet.ServletHolder;
+import org.eclipse.jetty.util.security.Constraint;
+import org.eclipse.jetty.util.security.Password;
 
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
@@ -81,6 +85,13 @@ public abstract class HttpWagonTestCase
     public static final int SC_TOO_MANY_REQUESTS = 429;
 
     private Server server;
+    private ServerConnector connector;
+
+    protected int getLocalPort( Server server )
+    {
+        Connector connector = server.getConnectors()[0];
+        return ( ( ServerConnector ) connector ).getLocalPort();
+    }
 
     protected void setupWagonTestingFixtures()
         throws Exception
@@ -97,7 +108,10 @@ public abstract class HttpWagonTestCase
         FileUtils.deleteDirectory( repositoryDirectory );
         repositoryDirectory.mkdirs();
 
-        server = new Server( 0 );
+        server = new Server( );
+        //connector = new ServerConnector( server, new HttpConnectionFactory( new HttpConfiguration() ) );
+        //server.addConnector( connector );
+        connector = addConnector( server );
 
         PutHandler putHandler = new PutHandler( repositoryDirectory );
 
@@ -107,8 +121,6 @@ public abstract class HttpWagonTestCase
         handlers.addHandler( context );
         server.setHandler( handlers );
 
-        addConnectors( server );
-
         server.start();
 
         testRepository.setUrl( getTestRepositoryUrl() );
@@ -121,7 +133,7 @@ public abstract class HttpWagonTestCase
         {
             return 0;
         }
-        return server.getConnectors()[0].getLocalPort();
+        return connector.getLocalPort();
     }
 
     protected ServletContextHandler createContext( Server server, File repositoryDirectory )
@@ -162,14 +174,14 @@ public abstract class HttpWagonTestCase
 
         setHttpHeaders( wagon, properties );
 
-        Server server = new Server( 0 );
+        Server server = new Server(  );
         TestHeaderHandler handler = new TestHeaderHandler();
         server.setHandler( handler );
-        addConnectors( server );
+        ServerConnector serverConnector = addConnector( server );
         server.start();
 
         wagon.connect(
-            new Repository( "id", getProtocol() + "://localhost:" + server.getConnectors()[0].getLocalPort() ) );
+            new Repository( "id", getProtocol() + "://localhost:" + serverConnector.getLocalPort() ) );
 
         wagon.getToStream( "resource", new ByteArrayOutputStream() );
 
@@ -194,14 +206,15 @@ public abstract class HttpWagonTestCase
         Method setHttpHeaders = wagon.getClass().getMethod( "setHttpHeaders", Properties.class );
         setHttpHeaders.invoke( wagon, properties );
 
-        Server server = new Server( 0 );
+        Server server = new Server( );
+        ServerConnector serverConnector = addConnector( server );
         TestHeaderHandler handler = new TestHeaderHandler();
         server.setHandler( handler );
-        addConnectors( server );
+        addConnector( server );
         server.start();
 
         wagon.connect(
-            new Repository( "id", getProtocol() + "://localhost:" + server.getConnectors()[0].getLocalPort() ) );
+            new Repository( "id", getProtocol() + "://localhost:" + serverConnector.getLocalPort() ) );
 
         wagon.getToStream( "resource", new ByteArrayOutputStream() );
 
@@ -216,13 +229,12 @@ public abstract class HttpWagonTestCase
         throws Exception
     {
         StreamingWagon wagon = (StreamingWagon) getWagon();
-        Server server = new Server( 0 );
+        Server server = new Server(  );
         TestHeaderHandler handler = new TestHeaderHandler();
         server.setHandler( handler );
-        addConnectors( server );
+        addConnector( server );
         server.start();
-        wagon.connect( new Repository( "id", getProtocol() + "://localhost:"
-          + server.getConnectors()[0].getLocalPort() ) );
+        wagon.connect( new Repository( "id", getProtocol() + "://localhost:" + getLocalPort( server ) ) );
         wagon.getToStream( "resource", new ByteArrayOutputStream() );
         wagon.disconnect();
         server.stop();
@@ -247,13 +259,12 @@ public abstract class HttpWagonTestCase
         Method setHttpHeaders = wagon.getClass().getMethod( "setHttpHeaders", Properties.class );
         setHttpHeaders.invoke( wagon, headers2 );
 
-        Server server = new Server( 0 );
+        Server server = new Server(  );
         TestHeaderHandler handler = new TestHeaderHandler();
         server.setHandler( handler );
-        addConnectors( server );
+        addConnector( server );
         server.start();
-        wagon.connect( new Repository( "id", getProtocol() + "://localhost:"
-          + server.getConnectors()[0].getLocalPort() ) );
+        wagon.connect( new Repository( "id", getProtocol() + "://localhost:" + getLocalPort( server ) ) );
         wagon.getToStream( "resource", new ByteArrayOutputStream() );
         wagon.disconnect();
         server.stop();
@@ -264,13 +275,17 @@ public abstract class HttpWagonTestCase
 
     protected abstract void setHttpHeaders( StreamingWagon wagon, Properties properties );
 
-    protected void addConnectors( Server server )
+    protected ServerConnector addConnector( Server server )
     {
+        ServerConnector serverConnector =
+            new ServerConnector( server, new HttpConnectionFactory( new HttpConfiguration() ) );
+        server.addConnector( serverConnector );
+        return serverConnector;
     }
 
     protected String getRepositoryUrl( Server server )
     {
-        int localPort = server.getConnectors()[0].getLocalPort();
+        int localPort = getLocalPort( server );
         return getProtocol() + "://localhost:" + localPort;
     }
 
@@ -309,7 +324,7 @@ public abstract class HttpWagonTestCase
         try
         {
 
-            Server server = new Server( 0 );
+            Server server = new Server(  );
             final AtomicBoolean called = new AtomicBoolean();
 
             AbstractHandler handler = new AbstractHandler()
@@ -333,7 +348,7 @@ public abstract class HttpWagonTestCase
             };
 
             server.setHandler( handler );
-            addConnectors( server );
+            ServerConnector serverConnector = addConnector( server );
             server.start();
 
             wagon.connect( new Repository( "id", getRepositoryUrl( server ) ) );
@@ -388,11 +403,11 @@ public abstract class HttpWagonTestCase
     {
         StreamingWagon wagon = (StreamingWagon) getWagon();
 
-        Server server = new Server( 0 );
+        Server server = new Server(  );
         StatusHandler handler = new StatusHandler();
         handler.setStatusToReturn( status );
         server.setHandler( handler );
-        addConnectors( server );
+        addConnector( server );
         server.start();
 
         wagon.connect( new Repository( "id", getRepositoryUrl( server ) ) );
@@ -479,9 +494,9 @@ public abstract class HttpWagonTestCase
             };
 
             StreamingWagon wagon = (StreamingWagon) getWagon();
-            Server server = new Server( 0 );
+            Server server = new Server(  );
             server.setHandler( handler );
-            addConnectors( server );
+            addConnector( server );
             server.start();
             wagon.connect( new Repository( "id", getRepositoryUrl( server ) ) );
 
@@ -510,11 +525,11 @@ public abstract class HttpWagonTestCase
     {
         StreamingWagon wagon = (StreamingWagon) getWagon();
 
-        Server server = new Server( 0 );
+        Server server = new Server( );
         StatusHandler handler = new StatusHandler();
         handler.setStatusToReturn( status );
         server.setHandler( handler );
-        addConnectors( server );
+        addConnector( server );
         server.start();
 
         wagon.connect( new Repository( "id", getRepositoryUrl( server ) ) );
@@ -545,7 +560,7 @@ public abstract class HttpWagonTestCase
     public void testGzipGet()
         throws Exception
     {
-        Server server = new Server( getTestRepositoryPort() );
+        Server server = new Server( );
 
         String localRepositoryPath = FileTestUtils.getTestOutputDir().toString();
         ServletContextHandler root = new ServletContextHandler( ServletContextHandler.SESSIONS );
@@ -553,7 +568,7 @@ public abstract class HttpWagonTestCase
         ServletHolder servletHolder = new ServletHolder( new DefaultServlet() );
         servletHolder.setInitParameter( "gzip", "true" );
         root.addServlet( servletHolder, "/*" );
-        addConnectors( server );
+        addConnector( server );
         server.setHandler( root );
         server.start();
 
@@ -661,16 +676,16 @@ public abstract class HttpWagonTestCase
     {
         StreamingWagon wagon = (StreamingWagon) getWagon();
 
-        Server realServer = new Server( 0 );
+        Server realServer = new Server(  );
         TestHeaderHandler handler = new TestHeaderHandler();
 
         realServer.setHandler( handler );
-        addConnectors( realServer );
+        addConnector( realServer );
         realServer.start();
 
-        Server redirectServer = new Server( 0 );
+        Server redirectServer = new Server(  );
 
-        addConnectors( redirectServer );
+        addConnector( redirectServer );
 
         String protocol = getProtocol();
 
@@ -685,7 +700,7 @@ public abstract class HttpWagonTestCase
             protocol = "https";
         }
 
-        String redirectUrl = protocol + "://localhost:" + realServer.getConnectors()[0].getLocalPort();
+        String redirectUrl = protocol + "://localhost:" + getLocalPort( realServer );
 
         RedirectHandler redirectHandler =
             new RedirectHandler( "See Other", HttpServletResponse.SC_SEE_OTHER, redirectUrl, null );
@@ -698,9 +713,7 @@ public abstract class HttpWagonTestCase
 
         File tmpResult = File.createTempFile( "foo", "get" );
 
-        FileOutputStream fileOutputStream = new FileOutputStream( tmpResult );
-
-        try
+        try ( FileOutputStream fileOutputStream = new FileOutputStream( tmpResult ) )
         {
             wagon.getToStream( "resource", fileOutputStream );
             fileOutputStream.flush();
@@ -727,16 +740,16 @@ public abstract class HttpWagonTestCase
     {
         StreamingWagon wagon = (StreamingWagon) getWagon();
 
-        Server realServer = new Server( 0 );
+        Server realServer = new Server( );
         TestHeaderHandler handler = new TestHeaderHandler();
 
         realServer.setHandler( handler );
-        addConnectors( realServer );
+        addConnector( realServer );
         realServer.start();
 
-        Server redirectServer = new Server( 0 );
+        Server redirectServer = new Server( );
 
-        addConnectors( redirectServer );
+        addConnector( redirectServer );
 
         String protocol = getProtocol();
 
@@ -751,7 +764,7 @@ public abstract class HttpWagonTestCase
             protocol = "https";
         }
 
-        String redirectUrl = protocol + "://localhost:" + realServer.getConnectors()[0].getLocalPort();
+        String redirectUrl = protocol + "://localhost:" + getLocalPort( realServer );
 
         RedirectHandler redirectHandler =
             new RedirectHandler( "See Other", HttpServletResponse.SC_SEE_OTHER, redirectUrl, null );
@@ -788,9 +801,9 @@ public abstract class HttpWagonTestCase
     public void testRedirectPutFromStreamWithFullUrl()
         throws Exception
     {
-        Server realServer = new Server( 0 );
+        Server realServer = new Server( );
 
-        addConnectors( realServer );
+        addConnector( realServer );
 
         File repositoryDirectory = getRepositoryDirectory();
         FileUtils.deleteDirectory( repositoryDirectory );
@@ -802,9 +815,9 @@ public abstract class HttpWagonTestCase
 
         realServer.start();
 
-        Server redirectServer = new Server( 0 );
+        Server redirectServer = new Server( );
 
-        addConnectors( redirectServer );
+        addConnector( redirectServer );
 
         String protocol = getProtocol();
 
@@ -819,7 +832,7 @@ public abstract class HttpWagonTestCase
             protocol = "https";
         }
 
-        String redirectUrl = protocol + "://localhost:" + realServer.getConnectors()[0].getLocalPort();
+        String redirectUrl = protocol + "://localhost:" + getLocalPort( realServer );
 
         RedirectHandler redirectHandler =
             new RedirectHandler( "See Other", HttpServletResponse.SC_SEE_OTHER, redirectUrl, repositoryDirectory );
@@ -843,8 +856,7 @@ public abstract class HttpWagonTestCase
             String content = "put top secret";
             FileUtils.fileWrite( tempFile.getAbsolutePath(), content );
 
-            FileInputStream fileInputStream = new FileInputStream( tempFile );
-            try
+            try ( FileInputStream fileInputStream = new FileInputStream( tempFile ) )
             {
                 wagon.putFromStream( fileInputStream, "test-secured-put-resource", content.length(), -1 );
                 assertEquals( content, FileUtils.fileRead( sourceFile.getAbsolutePath() ) );
@@ -854,7 +866,6 @@ public abstract class HttpWagonTestCase
             finally
             {
                 wagon.disconnect();
-                fileInputStream.close();
                 tempFile.delete();
             }
 
@@ -876,8 +887,8 @@ public abstract class HttpWagonTestCase
     public void testRedirectPutFromStreamRelativeUrl()
         throws Exception
     {
-        Server realServer = new Server( 0 );
-        addConnectors( realServer );
+        Server realServer = new Server( );
+        addConnector( realServer );
         File repositoryDirectory = getRepositoryDirectory();
         FileUtils.deleteDirectory( repositoryDirectory );
         repositoryDirectory.mkdirs();
@@ -888,9 +899,9 @@ public abstract class HttpWagonTestCase
 
         realServer.start();
 
-        Server redirectServer = new Server( 0 );
+        Server redirectServer = new Server( );
 
-        addConnectors( redirectServer );
+        addConnector( redirectServer );
 
         RedirectHandler redirectHandler =
             new RedirectHandler( "See Other", HttpServletResponse.SC_SEE_OTHER, "/redirectRequest/foo",
@@ -915,8 +926,7 @@ public abstract class HttpWagonTestCase
             String content = "put top secret";
             FileUtils.fileWrite( tempFile.getAbsolutePath(), content );
 
-            FileInputStream fileInputStream = new FileInputStream( tempFile );
-            try
+            try ( FileInputStream fileInputStream = new FileInputStream( tempFile ) )
             {
                 wagon.putFromStream( fileInputStream, "test-secured-put-resource", content.length(), -1 );
                 assertEquals( content, FileUtils.fileRead( sourceFile.getAbsolutePath() ) );
@@ -926,7 +936,6 @@ public abstract class HttpWagonTestCase
             finally
             {
                 wagon.disconnect();
-                fileInputStream.close();
                 tempFile.delete();
             }
 
@@ -967,9 +976,9 @@ public abstract class HttpWagonTestCase
     public void testRedirectPutFileWithFullUrl()
         throws Exception
     {
-        Server realServer = new Server( 0 );
+        Server realServer = new Server( );
 
-        addConnectors( realServer );
+        addConnector( realServer );
 
         File repositoryDirectory = getRepositoryDirectory();
         FileUtils.deleteDirectory( repositoryDirectory );
@@ -981,9 +990,9 @@ public abstract class HttpWagonTestCase
 
         realServer.start();
 
-        Server redirectServer = new Server( 0 );
+        Server redirectServer = new Server( );
 
-        addConnectors( redirectServer );
+        addConnector( redirectServer );
 
         String protocol = getProtocol();
 
@@ -998,7 +1007,7 @@ public abstract class HttpWagonTestCase
             protocol = "https";
         }
 
-        String redirectUrl = protocol + "://localhost:" + realServer.getConnectors()[0].getLocalPort();
+        String redirectUrl = protocol + "://localhost:" + getLocalPort( realServer );
 
         RedirectHandler redirectHandler =
             new RedirectHandler( "See Other", HttpServletResponse.SC_SEE_OTHER, redirectUrl, repositoryDirectory );
@@ -1047,8 +1056,8 @@ public abstract class HttpWagonTestCase
     public void testRedirectPutFileRelativeUrl()
         throws Exception
     {
-        Server realServer = new Server( 0 );
-        addConnectors( realServer );
+        Server realServer = new Server( );
+        addConnector( realServer );
         File repositoryDirectory = getRepositoryDirectory();
         FileUtils.deleteDirectory( repositoryDirectory );
         repositoryDirectory.mkdirs();
@@ -1059,9 +1068,9 @@ public abstract class HttpWagonTestCase
 
         realServer.start();
 
-        Server redirectServer = new Server( 0 );
+        Server redirectServer = new Server( );
 
-        addConnectors( redirectServer );
+        addConnector( redirectServer );
 
         RedirectHandler redirectHandler =
             new RedirectHandler( "See Other", HttpServletResponse.SC_SEE_OTHER, "/redirectRequest/foo",
@@ -1141,7 +1150,7 @@ public abstract class HttpWagonTestCase
                 PutHandler putHandler = new PutHandler( this.repositoryDirectory );
                 putHandler.handle( target, baseRequest, request, response );
                 handlerRequestResponses.add(
-                    new HandlerRequestResponse( request.getMethod(), ( (Response) response ).getStatus(),
+                    new HandlerRequestResponse( request.getMethod(), response.getStatus(),
                                                 request.getRequestURI() ) );
                 return;
             }
@@ -1150,7 +1159,7 @@ public abstract class HttpWagonTestCase
             baseRequest.setHandled( true );
 
             handlerRequestResponses.add(
-                new HandlerRequestResponse( request.getMethod(), ( (Response) response ).getStatus(),
+                new HandlerRequestResponse( request.getMethod(), response.getStatus(),
                                             request.getRequestURI() ) );
         }
 
@@ -1168,13 +1177,15 @@ public abstract class HttpWagonTestCase
         Thread.sleep( 5001L );
         // CHECKSTYLE_ON: MagicNumber
 
-        Server proxyServer = new Server( 0 );
-
+        Server proxyServer = new Server( );
+        ServerConnector serverConnector =
+            new ServerConnector( proxyServer, new HttpConnectionFactory( new HttpConfiguration() ) );
+        proxyServer.addConnector( serverConnector );
         proxyServer.setHandler( handler );
 
         proxyServer.start();
 
-        proxyInfo.setPort( proxyServer.getConnectors()[0].getLocalPort() );
+        proxyInfo.setPort( getLocalPort( proxyServer ) );
 
         System.out.println(
             "start proxy on host/port " + proxyInfo.getHost() + "/" + proxyInfo.getPort() + " with non proxyHosts "
@@ -1226,13 +1237,16 @@ public abstract class HttpWagonTestCase
         Thread.sleep( 5001L );
         // CHECKSTYLE_ON: MagicNumber
 
-        Server proxyServer = new Server( 0 );
+        Server proxyServer = new Server( );
+        ServerConnector serverConnector =
+            new ServerConnector( proxyServer, new HttpConnectionFactory( new HttpConfiguration() ) );
+        proxyServer.addConnector( serverConnector );
 
         proxyServer.setHandler( handler );
 
         proxyServer.start();
 
-        proxyInfoProvider.getProxyInfo( null ).setPort( proxyServer.getConnectors()[0].getLocalPort() );
+        proxyInfoProvider.getProxyInfo( null ).setPort( getLocalPort( proxyServer ) );
 
         System.out.println( "start proxy on host/port " + proxyInfoProvider.getProxyInfo( null ).getHost() + "/"
                                 + proxyInfoProvider.getProxyInfo( null ).getPort() + " with non proxyHosts "
@@ -1515,7 +1529,7 @@ public abstract class HttpWagonTestCase
 
     private Server createSecurityServer( String localRepositoryPath )
     {
-        Server server = new Server( 0 );
+        Server server = new Server( );
 
         SecurityHandler sh = createSecurityHandler();
 
@@ -1527,7 +1541,7 @@ public abstract class HttpWagonTestCase
         root.addServlet( servletHolder, "/*" );
 
         server.setHandler( root );
-        addConnectors( server );
+        addConnector( server );
         return server;
     }
 
@@ -1618,7 +1632,7 @@ public abstract class HttpWagonTestCase
         {
 
             StreamingWagon wagon = (StreamingWagon) getWagon();
-            Server server = new Server( 0 );
+            Server server = new Server( );
             final AtomicBoolean called = new AtomicBoolean();
 
             AbstractHandler handler = new AbstractHandler()
@@ -1641,7 +1655,7 @@ public abstract class HttpWagonTestCase
             };
 
             server.setHandler( handler );
-            addConnectors( server );
+            addConnector( server );
             server.start();
 
             wagon.connect( new Repository( "id", getRepositoryUrl( server ) ) );
@@ -1677,11 +1691,11 @@ public abstract class HttpWagonTestCase
     {
         StreamingWagon wagon = (StreamingWagon) getWagon();
 
-        Server server = new Server( 0 );
+        Server server = new Server( );
         StatusHandler handler = new StatusHandler();
         handler.setStatusToReturn( status );
         server.setHandler( handler );
-        addConnectors( server );
+        addConnector( server );
         server.start();
 
         wagon.connect( new Repository( "id", getRepositoryUrl( server ) ) );
@@ -1755,7 +1769,7 @@ public abstract class HttpWagonTestCase
         throws Exception
     {
         String localRepositoryPath = FileTestUtils.getTestOutputDir().toString();
-        Server server = new Server( 0 );
+        Server server = new Server( );
 
         TestSecurityHandler sh = createSecurityHandler();
 
@@ -1763,7 +1777,7 @@ public abstract class HttpWagonTestCase
 
         sh.setHandler( putHandler );
         server.setHandler( sh );
-        addConnectors( server );
+        addConnector( server );
         server.start();
 
         StreamingWagon wagon = (StreamingWagon) getWagon();
@@ -1824,7 +1838,7 @@ public abstract class HttpWagonTestCase
         throws Exception
     {
         String localRepositoryPath = FileTestUtils.getTestOutputDir().toString();
-        Server server = new Server( 0 );
+        Server server = new Server( );
 
         TestSecurityHandler sh = createSecurityHandler();
 
@@ -1839,7 +1853,7 @@ public abstract class HttpWagonTestCase
         {
             server.setHandler( putHandler );
         }
-        addConnectors( server );
+        addConnector( server );
         server.start();
 
         StreamingWagon wagon = (StreamingWagon) getWagon();
@@ -1865,16 +1879,13 @@ public abstract class HttpWagonTestCase
                 String content = "put top secret";
                 FileUtils.fileWrite( tempFile.getAbsolutePath(), content );
 
-                FileInputStream fileInputStream = new FileInputStream( tempFile );
-                try
+                try ( FileInputStream fileInputStream = new FileInputStream( tempFile ) )
                 {
                     wagon.putFromStream( fileInputStream, "test-secured-put-resource", content.length(), -1 );
                 }
                 finally
                 {
-                    fileInputStream.close();
                     tempFile.delete();
-
                 }
 
                 assertEquals( content, FileUtils.fileRead( sourceFile.getAbsolutePath() ) );
