@@ -19,13 +19,19 @@ package org.apache.maven.wagon.providers.webdav;
  * under the License.
  */
 
-import org.apache.commons.httpclient.HttpStatus;
+import org.apache.http.HttpException;
+import org.apache.http.HttpHost;
+import org.apache.http.HttpStatus;
+import org.apache.http.auth.AuthScope;
+import org.apache.http.client.methods.CloseableHttpResponse;
+import org.apache.http.client.methods.HttpUriRequest;
+import org.apache.http.impl.auth.BasicScheme;
 import org.apache.jackrabbit.webdav.DavConstants;
 import org.apache.jackrabbit.webdav.DavException;
 import org.apache.jackrabbit.webdav.MultiStatus;
 import org.apache.jackrabbit.webdav.MultiStatusResponse;
-import org.apache.jackrabbit.webdav.client.methods.MkColMethod;
-import org.apache.jackrabbit.webdav.client.methods.PropFindMethod;
+import org.apache.jackrabbit.webdav.client.methods.HttpMkcol;
+import org.apache.jackrabbit.webdav.client.methods.HttpPropfind;
 import org.apache.jackrabbit.webdav.property.DavProperty;
 import org.apache.jackrabbit.webdav.property.DavPropertyName;
 import org.apache.jackrabbit.webdav.property.DavPropertyNameSet;
@@ -36,20 +42,23 @@ import org.apache.maven.wagon.TransferFailedException;
 import org.apache.maven.wagon.WagonConstants;
 import org.apache.maven.wagon.authorization.AuthorizationException;
 import org.apache.maven.wagon.repository.Repository;
+import org.apache.maven.wagon.shared.http.AbstractHttpClientWagon;
 import org.codehaus.plexus.util.FileUtils;
 import org.codehaus.plexus.util.StringUtils;
 import org.w3c.dom.Node;
 
 import java.io.File;
 import java.io.IOException;
+import java.io.InputStream;
 import java.net.URLDecoder;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Properties;
 
 /**
  * <p>WebDavWagon</p>
  * <p/>
- * <p>Allows using a webdav remote repository for downloads and deployments</p>
+ * <p>Allows using a WebDAV remote repository for downloads and deployments</p>
  *
  * @author <a href="mailto:hisidro@exist.com">Henry Isidro</a>
  * @author <a href="mailto:joakime@apache.org">Joakim Erdfelt</a>
@@ -69,7 +78,7 @@ public class WebDavWagon
     /**
      * Defines the protocol mapping to use.
      * <p/>
-     * First string is the user definition way to define a webdav url,
+     * First string is the user definition way to define a WebDAV url,
      * the second string is the internal representation of that url.
      * <p/>
      * NOTE: The order of the mapping becomes the search order.
@@ -92,6 +101,38 @@ public class WebDavWagon
         return true;
     }
 
+    private static final String DEFAULT_USER_AGENT = getDefaultUserAgent();
+
+    private static String getDefaultUserAgent()
+    {
+        Properties props = new Properties();
+
+        try ( InputStream is = AbstractHttpClientWagon.class.getResourceAsStream(
+            "/META-INF/maven/org.apache.maven.wagon/wagon-webdav-jackrabbit/pom.properties" ) )
+        {
+            props.load( is );
+            is.close();
+        }
+        catch ( Exception ignore )
+        {
+            // ignore
+        }
+
+        String ver = props.getProperty( "version", "unknown-version" );
+        return "Apache-Maven-Wagon/" + ver + " (Java " + System.getProperty( "java.version" ) + "; ";
+    }
+
+    @Override
+    protected String getUserAgent( HttpUriRequest method )
+    {
+        String userAgent = super.getUserAgent( method );
+        if ( userAgent == null )
+        {
+            return DEFAULT_USER_AGENT;
+        }
+        return userAgent;
+    }
+
     /**
      * Create directories in server as needed.
      * They are created one at a time until the whole path exists.
@@ -119,7 +160,7 @@ public class WebDavWagon
 
         // traverse backwards until we hit a directory that already exists (OK/NOT_ALLOWED), or that we were able to
         // create (CREATED), or until we get to the top of the path
-        int status = SC_NULL;
+        int status = -1;
         do
         {
             String url = baseUrl + "/" + navigator.getPath();
@@ -147,11 +188,23 @@ public class WebDavWagon
     private int doMkCol( String url )
         throws IOException
     {
-        MkColMethod method = null;
-        try
+        Repository repo = getRepository();
+        HttpHost targetHost = new HttpHost( repo.getHost(), repo.getPort(), repo.getProtocol() );
+        AuthScope targetScope = getBasicAuthScope().getScope( targetHost );
+
+        if ( getCredentialsProvider().getCredentials( targetScope ) != null )
         {
-            method = new MkColMethod( url );
-            return execute( method );
+            BasicScheme targetAuth = new BasicScheme();
+            getAuthCache().put( targetHost, targetAuth );
+        }
+        HttpMkcol method = new HttpMkcol( url );
+        try ( CloseableHttpResponse closeableHttpResponse = execute( method ) )
+        {
+            return closeableHttpResponse.getStatusLine().getStatusCode();
+        }
+        catch ( HttpException e )
+        {
+            throw new IOException( e.getMessage(), e );
         }
         finally
         {
@@ -163,7 +216,7 @@ public class WebDavWagon
     }
 
     /**
-     * Copy a directory from local system to remote webdav server
+     * Copy a directory from local system to remote WebDAV server
      *
      * @param sourceDirectory      the local directory
      * @param destinationDirectory the remote destination
@@ -188,21 +241,22 @@ public class WebDavWagon
             }
         }
     }
-
     private boolean isDirectory( String url )
         throws IOException, DavException
     {
         DavPropertyNameSet nameSet = new DavPropertyNameSet();
         nameSet.add( DavPropertyName.create( DavConstants.PROPERTY_RESOURCETYPE ) );
 
-        PropFindMethod method = null;
+        CloseableHttpResponse closeableHttpResponse = null;
+        HttpPropfind method = null;
         try
         {
-            method = new PropFindMethod( url, nameSet, DavConstants.DEPTH_0 );
-            execute( method );
-            if ( method.succeeded() )
+            method = new HttpPropfind( url, nameSet, DavConstants.DEPTH_0 );
+            closeableHttpResponse = execute( method );
+
+            if ( method.succeeded( closeableHttpResponse ) )
             {
-                MultiStatus multiStatus = method.getResponseBodyAsMultiStatus();
+                MultiStatus multiStatus = method.getResponseBodyAsMultiStatus( closeableHttpResponse );
                 MultiStatusResponse response = multiStatus.getResponses()[0];
                 DavPropertySet propertySet = response.getProperties( HttpStatus.SC_OK );
                 DavProperty<?> property = propertySet.get( DavConstants.PROPERTY_RESOURCETYPE );
@@ -214,12 +268,21 @@ public class WebDavWagon
             }
             return false;
         }
+        catch ( HttpException e )
+        {
+            throw new IOException( e.getMessage(), e );
+        }
         finally
         {
+            //TODO olamy: not sure we still need this!!
             if ( method != null )
             {
                 method.releaseConnection();
             }
+            if ( closeableHttpResponse != null )
+            {
+                closeableHttpResponse.close();
+            }
         }
     }
 
@@ -229,7 +292,8 @@ public class WebDavWagon
         String repositoryUrl = repository.getUrl();
         String url = repositoryUrl + ( repositoryUrl.endsWith( "/" ) ? "" : "/" ) + destinationDirectory;
 
-        PropFindMethod method = null;
+        HttpPropfind method = null;
+        CloseableHttpResponse closeableHttpResponse = null;
         try
         {
             if ( isDirectory( url ) )
@@ -237,27 +301,23 @@ public class WebDavWagon
                 DavPropertyNameSet nameSet = new DavPropertyNameSet();
                 nameSet.add( DavPropertyName.create( DavConstants.PROPERTY_DISPLAYNAME ) );
 
-                method = new PropFindMethod( url, nameSet, DavConstants.DEPTH_1 );
-                int status = execute( method );
-                if ( method.succeeded() )
+                method = new HttpPropfind( url, nameSet, DavConstants.DEPTH_1 );
+                closeableHttpResponse = execute( method );
+                if ( method.succeeded( closeableHttpResponse ) )
                 {
-                    ArrayList<String> dirs = new ArrayList<String>();
-                    MultiStatus multiStatus = method.getResponseBodyAsMultiStatus();
-
+                    ArrayList<String> dirs = new ArrayList<>();
+                    MultiStatus multiStatus = method.getResponseBodyAsMultiStatus( closeableHttpResponse );
                     for ( int i = 0; i < multiStatus.getResponses().length; i++ )
                     {
-
                         MultiStatusResponse response = multiStatus.getResponses()[i];
-
                         String entryUrl = response.getHref();
                         String fileName = PathUtils.filename( URLDecoder.decode( entryUrl ) );
                         if ( entryUrl.endsWith( "/" ) )
                         {
                             if ( i == 0 )
                             {
-                                // by design jackrabbit webdav sticks parent directory as the first entry
+                                // by design jackrabbit WebDAV sticks parent directory as the first entry
                                 // so we need to ignore this entry
-                           // http://www.nabble.com/Extra-entry-in-get-file-list-with-jackrabbit-webdav-td21262786.html
                                 // http://www.webdav.org/specs/rfc4918.html#rfc.section.9.1
                                 continue;
                             }
@@ -274,12 +334,16 @@ public class WebDavWagon
                     return dirs;
                 }
 
-                if ( status == HttpStatus.SC_NOT_FOUND )
+                if ( closeableHttpResponse.getStatusLine().getStatusCode() == HttpStatus.SC_NOT_FOUND )
                 {
                     throw new ResourceDoesNotExistException( "Destination directory does not exist: " + url );
                 }
             }
         }
+        catch ( HttpException e )
+        {
+            throw new TransferFailedException( e.getMessage(), e );
+        }
         catch ( DavException e )
         {
             throw new TransferFailedException( e.getMessage(), e );
@@ -290,10 +354,22 @@ public class WebDavWagon
         }
         finally
         {
+            //TODO olamy: not sure we still need this!!
             if ( method != null )
             {
                 method.releaseConnection();
             }
+            if ( closeableHttpResponse != null )
+            {
+                try
+                {
+                    closeableHttpResponse.close();
+                }
+                catch ( IOException e )
+                {
+                    // ignore
+                }
+            }
         }
         throw new ResourceDoesNotExistException(
             "Destination path exists but is not a " + "WebDAV collection (directory): " + url );
