@@ -1,8 +1,8 @@
 package org.apache.maven.wagon.providers.webdav;
 
-import org.eclipse.jetty.server.Connector;
 import org.eclipse.jetty.server.Server;
-import org.eclipse.jetty.server.ssl.SslSocketConnector;
+import org.eclipse.jetty.server.ServerConnector;
+import org.eclipse.jetty.util.ssl.SslContextFactory;
 
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
@@ -38,19 +38,21 @@ public class WebDavsWagonTest
         return "davs";
     }
 
-    protected void addConnectors( Server server )
+    protected ServerConnector addConnector( Server server )
     {
         System.setProperty( "javax.net.ssl.trustStore",
                             getTestFile( "src/test/resources/ssl/keystore" ).getAbsolutePath() );
 
-        SslSocketConnector connector = new SslSocketConnector();
-        connector.setPort( server.getConnectors()[0].getPort() );
-        connector.setKeystore( getTestPath( "src/test/resources/ssl/keystore" ) );
-        connector.setPassword( "wagonhttp" );
-        connector.setKeyPassword( "wagonhttp" );
-        connector.setTruststore( getTestPath( "src/test/resources/ssl/keystore" ) );
-        connector.setTrustPassword( "wagonhttp" );
-        server.setConnectors( new Connector[] { connector } );
+        SslContextFactory sslContextFactory = new SslContextFactory();
+        sslContextFactory.setKeyStorePath( getTestPath( "src/test/resources/ssl/keystore" ) );
+        sslContextFactory.setKeyStorePassword( "wagonhttp" );
+        sslContextFactory.setKeyManagerPassword( "wagonhttp" );
+        sslContextFactory.setTrustStorePath( getTestPath( "src/test/resources/ssl/keystore" ) );
+        sslContextFactory.setTrustStorePassword( "wagonhttp" );
+
+        ServerConnector serverConnector = new ServerConnector( server, sslContextFactory );
+        server.addConnector( serverConnector );
+        return serverConnector;
     }
 
 }
